@@ -20,7 +20,7 @@
 
 
 //#include "GL/gl.h"
-//#include <GL/glut.h>
+#include <GL/glut.h>
 #include <GL/glu.h>
 #include <math.h>
 
@@ -86,7 +86,7 @@ void *pdp_3d_draw_get_command_object(t_pdp_3d_draw *x)
 
 /* object drawing methods */
 
-static void draw_clear(t_drawcommand *x)
+static void draw_clear(t_drawcommand *x __attribute__((__unused__)))
 {
     glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
@@ -209,7 +209,7 @@ static void draw_wtorus(t_drawcommand *x)
     if (n < 1) n = 20;
     if (m < 1) m = n;
 
-    // glutWireTorus(ri, ro, n, m);
+    glutWireTorus(ri, ro, n, m);
 
 }
 
@@ -222,8 +222,8 @@ static void draw_torus(t_drawcommand *x)
 
     if (n < 1) n = 20;
     if (m < 1) m = n;
-
-    // glutSolidTorus(ri, ro, n, m);
+    
+    glutSolidTorus(ri, ro, n, m);
 
 }
 
@@ -237,7 +237,7 @@ static void draw_cone(t_drawcommand *x)
     if (n < 1) n = 20;
     if (m < 1) m = n;
 
-    // glutSolidCone(base, height, n, m);
+    glutSolidCone(base, height, n, m);
 
 }
 
@@ -251,21 +251,21 @@ static void draw_wcone(t_drawcommand *x)
     if (n < 1) n = 20;
     if (m < 1) m = n;
 
-    // glutWireCone(base, height, n, m);
+    glutWireCone(base, height, n, m);
 
 }
 
 static void draw_wteapot(t_drawcommand *x)
 {
     float f = x->x_p0;
-    // glutWireTeapot(f);
+    glutWireTeapot(f);
 
 }
 
 static void draw_teapot(t_drawcommand *x)
 {
     float f = x->x_p0;
-    // glutSolidTeapot(f);
+    glutSolidTeapot(f);
 
 }
 
@@ -278,7 +278,7 @@ static void draw_wsphere(t_drawcommand *x)
     if (n < 1) n = 20;
     if (m < 1) m = n;
 
-    // glutWireSphere(f, n, m);
+    glutWireSphere(f, n, m);
 
 }
 
@@ -293,19 +293,21 @@ static void draw_sphere(t_drawcommand *x)
 
     gluSphere(x->x_quadric, f, n, m);
 
-    //glutSolidSphere(f, n, m);
+    glutSolidSphere(f, n, m);
 
 }
 
-static void draw_dodeca(t_drawcommand *x){ /* glutSolidDodecahedron(); */ }
-static void draw_octa(t_drawcommand *x)  { /* glutSolidOctahedron(); */ }
-static void draw_tetra(t_drawcommand *x) { /* glutSolidTetrahedron(); */ }
-static void draw_icosa(t_drawcommand *x) { /* glutSolidIcosahedron(); */ } 
+#define UNUSED __attribute__((__unused__))
 
-static void draw_wdodeca(t_drawcommand *x){ /* glutWireDodecahedron(); */ }
-static void draw_wocta(t_drawcommand *x)  { /* glutWireOctahedron(); */ }
-static void draw_wtetra(t_drawcommand *x) { /* glutWireTetrahedron(); */ }
-static void draw_wicosa(t_drawcommand *x) { /* glutWireIcosahedron(); */ }
+static void draw_dodeca(t_drawcommand *x UNUSED){ glutSolidDodecahedron(); }
+static void draw_octa(t_drawcommand *x UNUSED)  { glutSolidOctahedron(); }
+static void draw_tetra(t_drawcommand *x UNUSED) { glutSolidTetrahedron(); }
+static void draw_icosa(t_drawcommand *x UNUSED) { glutSolidIcosahedron(); } 
+
+static void draw_wdodeca(t_drawcommand *x UNUSED){ glutWireDodecahedron(); }
+static void draw_wocta(t_drawcommand *x UNUSED)  { glutWireOctahedron(); }
+static void draw_wtetra(t_drawcommand *x UNUSED) { glutWireTetrahedron(); }
+static void draw_wicosa(t_drawcommand *x UNUSED) { glutWireIcosahedron(); }
 
 
 
@@ -488,6 +490,11 @@ extern "C"
 void pdp_3d_draw_setup(void)
 {
 
+    // FIXME: The GLUT dependency has been added in the revival of 3DP 2013-10
+    // It might be best to remove it again and just copy the drawing routines.
+    int argc = 0;
+    glutInit(&argc, NULL);
+
 
     pdp_3d_draw_class = class_new(gensym("3dp_draw"), (t_newmethod)pdp_3d_draw_new,
     	(t_method)pdp_3d_draw_free, sizeof(t_pdp_3d_draw), 0, A_SYMBOL, 
