@@ -59,7 +59,7 @@ static void pdp_3d_for_count(t_pdp_3d_for *x, t_floatarg f)
 }
 
 
-static void pdp_3d_for_free(t_pdp_3d_for *x)
+static void pdp_3d_for_free(t_pdp_3d_for *x __attribute__((__unused__)))
 {
 }
 
