@@ -1,7 +1,7 @@
 
 /*
  *   Pure Data Packet system file. pdp logging.
- *   Copyright (c) by Tom Schouten <pdp@zzz.kotnet.org>
+ *   Copyright (c) by Tom Schouten <tom@zwizwa.be>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,14 +29,14 @@
 /* list printing should be moved here too */
 
 /* write a message to log (console) */
-void pdp_post_n(char *fmt, ...)
+void _pdp_post_n(char *fmt, ...)
 {
     va_list ap;
     va_start(ap, fmt);
     vfprintf(stderr, fmt, ap);
     va_end(ap);
 }
-void pdp_post(char *fmt, ...)
+void _pdp_post(char *fmt, ...)
 {
     va_list ap;
     va_start(ap, fmt);
